summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xupdate.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/update.sh b/update.sh
index 34c64969..28dfeca1 100755
--- a/update.sh
+++ b/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
#automated script to update aethyra from SVN
#author=Blame <blame@aethyra.com>
-#last modified 2008-09-21 Blame
+#last modified 2008-12-03 Tametomo
file=~/src/aethyra
file1=~/src
# test for the aethyra client folder
if [ -e $file ]; then
#change to the aethyra directory
cd $file;
- #issue the svn update command
- svn up;
+ #issue the git update command
+ git pull;
#issue the autobuild command
./autobuild.sh;
echo "Aethyra has been updated"
@@ -19,8 +19,8 @@ else
mkdir $file1
#change to directory /home/user-name/src
cd $file1
- #execute the svn command to download the client files
- svn co svn://www.aethyra.org/client/trunk aethyra
+ #execute the git command to download the client files
+ git clone git://gitorious.org/tmw/aethyra.git
#issue the auto build script to compile the client
./autobuild
echo "congratulations on installing aethyra enjoy"
@@ -1,15 +1,15 @@
#!/bin/bash
-#automated script to update aethyra from SVN
+#automated script to update aethyra from git
#author=Blame <blame@aethyra.com>